'use strict';

var _regeneratorRuntime = require('babel-runtime/regenerator')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _should = require('should');

var _should2 = _interopRequireDefault(_should);

var _appRootPath = require('app-root-path');

var _appRootPath2 = _interopRequireDefault(_appRootPath);

var _util = require('./util');

var _util2 = _interopRequireDefault(_util);

var q = "SELECT 'John Doe'::text AS name";
var qParam = "SELECT $1::text AS name";
var param = 'John Doe';

describe('pg-util', function () {
  before(function () {
    var pathToSQLFiles = _path2['default'].join(_appRootPath2['default'].path, '/resources/tests/sql');
    var db = (0, _util2['default'])(null, pathToSQLFiles);
    this.db = db;
  });

  describe('#getClient', function () {
    it('should get a client', function callee$2$0() {
      var client;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;

            _should2['default'].exist(client);
            _should2['default'].exist(client.query);
            client.query.should.be.a.Function();

          case 6:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });
  });

  describe('#query', function () {
    it('should perform a query', function callee$2$0() {
      var rows;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.query(q));

          case 2:
            rows = context$3$0.sent;

            _should2['default'].equal(rows[0].name, param);

          case 4:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should perform a parameterized query', function callee$2$0() {
      var rows;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.query(qParam, [param]));

          case 2:
            rows = context$3$0.sent;

            _should2['default'].equal(rows[0].name, param);

          case 4:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should perform a query with a specified client', function callee$2$0() {
      var client, rows;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;
            context$3$0.next = 5;
            return _regeneratorRuntime.awrap(this.db.query(client, q));

          case 5:
            rows = context$3$0.sent;

            _should2['default'].equal(rows[0].name, param);

          case 7:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should perform a parameterized query with a specified client', function callee$2$0() {
      var client, rows;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;
            context$3$0.next = 5;
            return _regeneratorRuntime.awrap(this.db.query(client, qParam, [param]));

          case 5:
            rows = context$3$0.sent;

            _should2['default'].equal(rows[0].name, param);

          case 7:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });
  });

  describe('#one', function () {
    it('should run a query returning the first row', function callee$2$0() {
      var row;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.one(q));

          case 2:
            row = context$3$0.sent;

            _should2['default'].equal(row.name, param);

          case 4:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query returning the first row (parameterized)', function callee$2$0() {
      var row;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.one(qParam, [param]));

          case 2:
            row = context$3$0.sent;

            _should2['default'].equal(row.name, param);

          case 4:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query returning the first row with a specified client', function callee$2$0() {
      var client, row;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;
            context$3$0.next = 5;
            return _regeneratorRuntime.awrap(this.db.one(client, q));

          case 5:
            row = context$3$0.sent;

            _should2['default'].equal(row.name, param);

          case 7:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query returning the first row with a specified client (parameterized)', function callee$2$0() {
      var client, row;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;
            context$3$0.next = 5;
            return _regeneratorRuntime.awrap(this.db.one(client, qParam, [param]));

          case 5:
            row = context$3$0.sent;

            _should2['default'].equal(row.name, param);

          case 7:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });
  });

  describe('#run', function () {
    it('should run a query using a given sql file', function callee$2$0() {
      var rows;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.run('select'));

          case 2:
            rows = context$3$0.sent;

            _should2['default'].equal(rows[0].name, param);

          case 4:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query using a given sql file (parameterized)', function callee$2$0() {
      var rows;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.run('select-param', [param]));

          case 2:
            rows = context$3$0.sent;

            _should2['default'].equal(rows[0].name, param);

          case 4:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query using a given sql file and client', function callee$2$0() {
      var client, rows;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;
            context$3$0.next = 5;
            return _regeneratorRuntime.awrap(this.db.run(client, 'select'));

          case 5:
            rows = context$3$0.sent;

            _should2['default'].equal(rows[0].name, param);

          case 7:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query using a given sql file and client (parameterized)', function callee$2$0() {
      var client, rows;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;
            context$3$0.next = 5;
            return _regeneratorRuntime.awrap(this.db.run(client, 'select-param', [param]));

          case 5:
            rows = context$3$0.sent;

            _should2['default'].equal(rows[0].name, param);

          case 7:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });
  });

  describe('#first', function () {
    it('should run a query returning the first row using a given sql file', function callee$2$0() {
      var row;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.first('select'));

          case 2:
            row = context$3$0.sent;

            _should2['default'].equal(row.name, param);

          case 4:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query returning the first row using a given sql file (parameterized)', function callee$2$0() {
      var row;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.first('select-param', [param]));

          case 2:
            row = context$3$0.sent;

            _should2['default'].equal(row.name, param);

          case 4:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query returning the first row using a given sql file and client', function callee$2$0() {
      var client, row;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;
            context$3$0.next = 5;
            return _regeneratorRuntime.awrap(this.db.first(client, 'select'));

          case 5:
            row = context$3$0.sent;

            _should2['default'].equal(row.name, param);

          case 7:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });

    it('should run a query returning the first row using a given sql file and client (parameterized)', function callee$2$0() {
      var client, row;
      return _regeneratorRuntime.async(function callee$2$0$(context$3$0) {
        while (1) switch (context$3$0.prev = context$3$0.next) {
          case 0:
            context$3$0.next = 2;
            return _regeneratorRuntime.awrap(this.db.getClient());

          case 2:
            client = context$3$0.sent;
            context$3$0.next = 5;
            return _regeneratorRuntime.awrap(this.db.first(client, 'select-param', [param]));

          case 5:
            row = context$3$0.sent;

            _should2['default'].equal(row.name, param);

          case 7:
          case 'end':
            return context$3$0.stop();
        }
      }, null, this);
    });
  });
});